@@ -30,7 +30,7 @@ spec :: Spec
 spec = do
   describe "watchersForR" $ do
     it "works" $ withAuth $ \auth -> do
-      cs <- executeRequest auth $ watchersForR "phadej" "github" GitHub.FetchAll 
+      cs <- executeRequest auth $ watchersForR "haskell-github" "github" GitHub.FetchAll
       cs `shouldSatisfy` isRight
       V.length (fromRightS cs) `shouldSatisfy` (> 10)
   describe "myStarredR" $ do
